@@ -17,6 +17,7 @@ DEFAULT_CONFIG = {
             common.SETTING_DELEG_MARKER: '@delegated',
             common.SETTING_DELEG_ACTION: common.DELEGATE_ACTION_NONE,
             common.SETTING_DELEG_TO: 'to',
+            common.SETTING_EXT_EDITOR: '',
             common.SETTING_ADD_CREATED: 'yes',
             common.SETTING_TASK_FORMAT: common.DEFAULT_TASK_FORMAT,
             common.SETTING_CLEAR_CONTEXT: '',
@@ -24,6 +25,7 @@ DEFAULT_CONFIG = {
             common.SETTING_CREATE_FROM_SEARCH: 'no',
             common.SETTING_AUTO_ID: 'no',
             common.SETTING_HIDE_SEQUENTIAL: 'yes',
+            common.SETTING_INFO_TIMEOUT: common.DEFAULT_INFO_TIMEOUT,
         },
         common.SETTING_GROUP_SYMBOLS: {
             common.SETTING_ICON_SELECTION: '',
