@@ -296,6 +296,9 @@ class Searcher:
             return True
 
         description = task.description
+        if description is None:
+            description = ''
+
         if not self.casesensitive:
             description = description.lower()
 
